# kplaylisk

m3u8 playlist builder.

# Install and run

```bash
pip3 install --upgrade pip
pip3 install kplaylisk

kplaylisk build path_to_folder_or_file_or_url_1 path_to_folder_or_file_or_url_2 ... path_to_folder_or_file_or_url_n \
                 /path/to/out.m3u8  # It will create file `/path/to/out.m3u8`. 
                                    # Type --help for more options
```
